# -*- coding:utf-8 -*-
from .Cpath import *

__title__ = 'cgai_path'
__version__ = '0.0.5'
__author__ = 'Master Zhang'
__author_email__ = '360014296@qq.com'
__license__ = 'GPLv3'
__description__ = """ 适用于CG行业的文件路径便捷操作 """

